"""Generated model names for requesty provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 86
"""

from __future__ import annotations

from typing import Literal


RequestyModels = Literal[
    "requesty:alibaba/qwen3-30b-a3b-instruct-2507",
    "requesty:alibaba/qwen3-coder-flash",
    "requesty:alibaba/qwen3-coder-plus",
    "requesty:alibaba/qwen3-max",
    "requesty:anthropic/claude-haiku-4-5",
    "requesty:anthropic/claude-opus-4-1",
    "requesty:anthropic/claude-opus-4-5",
    "requesty:anthropic/claude-sonnet-4-5",
    "requesty:azure/gpt-5.1",
    "requesty:azure/gpt-5.1@swedencentral",
    "requesty:bedrock/claude-haiku-4-5",
    "requesty:bedrock/claude-haiku-4-5@eu-central-1",
    "requesty:bedrock/claude-haiku-4-5@eu-north-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-1",
    "requesty:bedrock/claude-haiku-4-5@eu-west-3",
    "requesty:bedrock/claude-haiku-4-5@us-east-1",
    "requesty:bedrock/claude-haiku-4-5@us-east-2",
    "requesty:bedrock/claude-haiku-4-5@us-west-2",
    "requesty:bedrock/claude-opus-4-5",
    "requesty:deepinfra/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:deepinfra/deepseek-ai/DeepSeek-V3.1",
    "requesty:deepinfra/zai-org/GLM-4.5",
    "requesty:deepinfra/zai-org/GLM-4.5-Air",
    "requesty:groq/moonshotai/Kimi-K2-Instruct-0905",
    "requesty:groq/moonshotai/kimi-k2-instruct",
    "requesty:groq/openai/gpt-oss-120b",
    "requesty:groq/openai/gpt-oss-20b",
    "requesty:minimaxi/MiniMax-M2",
    "requesty:moonshot/kimi-k2-0711-preview",
    "requesty:moonshot/kimi-k2-0905-preview",
    "requesty:moonshot/kimi-k2-thinking",
    "requesty:moonshot/kimi-k2-thinking-turbo",
    "requesty:moonshot/kimi-k2-turbo-preview",
    "requesty:nebius/Qwen/Qwen3-Coder-480B-A35B-Instruct",
    "requesty:nebius/deepseek-ai/DeepSeek-V3-0324-fast",
    "requesty:nebius/moonshotai/Kimi-K2-Instruct",
    "requesty:nebius/zai-org/GLM-4.5",
    "requesty:novita/deepseek/deepseek-v3-0324",
    "requesty:novita/deepseek/deepseek-v3-turbo",
    "requesty:novita/deepseek/deepseek_v3",
    "requesty:novita/moonshotai/kimi-k2-instruct",
    "requesty:novita/zai-org/glm-4.5",
    "requesty:novita/zai-org/glm-4.6",
    "requesty:openai-responses/gpt-5",
    "requesty:openai-responses/gpt-5-codex",
    "requesty:openai-responses/gpt-5-mini",
    "requesty:openai-responses/gpt-5-nano",
    "requesty:openai-responses/gpt-5-pro",
    "requesty:openai-responses/gpt-5.1-codex",
    "requesty:openai-responses/o3-pro",
    "requesty:openai/gpt-5",
    "requesty:openai/gpt-5-chat",
    "requesty:openai/gpt-5-mini",
    "requesty:openai/gpt-5-mini:flex",
    "requesty:openai/gpt-5-mini:priority",
    "requesty:openai/gpt-5-nano",
    "requesty:openai/gpt-5-nano:flex",
    "requesty:openai/gpt-5.1",
    "requesty:openai/gpt-5.1-chat",
    "requesty:openai/gpt-5:flex",
    "requesty:openai/gpt-5:priority",
    "requesty:openai/o3-deep-research",
    "requesty:openai/o4-mini-deep-research",
    "requesty:parasail/parasail-deepseek-v3-0324",
    "requesty:parasail/parasail-glm-45",
    "requesty:parasail/parasail-kimi-k2-instruct",
    "requesty:parasail/parasail-qwen3-235b-a22b-instruct-2507",
    "requesty:together/deepseek-ai/DeepSeek-R1",
    "requesty:together/deepseek-ai/DeepSeek-V3",
    "requesty:vertex/claude-opus-4-5",
    "requesty:vertex/claude-opus-4-5@europe-west1",
    "requesty:vertex/claude-opus-4-5@us-east5",
    "requesty:vertex/gemini-2.5-flash-image-preview",
    "requesty:xai/grok-2-1212",
    "requesty:xai/grok-3",
    "requesty:xai/grok-3-mini",
    "requesty:xai/grok-3-mini:high",
    "requesty:xai/grok-3-mini:low",
    "requesty:xai/grok-4",
    "requesty:xai/grok-4-1-fast-non-reasoning",
    "requesty:xai/grok-4-1-fast-reasoning",
    "requesty:xai/grok-4-fast",
    "requesty:xai/grok-4-fast-non-reasoning",
    "requesty:xai/grok-code-fast-1",
    "requesty:zai/GLM-4.5",
    "requesty:zai/GLM-4.6",
]

__all__ = ["RequestyModels"]
