"""Generated model names for github provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 82
"""

from __future__ import annotations

from typing import Literal


GithubModels = Literal[
    "github:AI21-Jamba-1.5-Large",
    "github:AI21-Jamba-1.5-Mini",
    "github:Aurora",
    "github:BioEmu",
    "github:Codestral-2501",
    "github:Cohere-command-r",
    "github:Cohere-command-r-08-2024",
    "github:Cohere-command-r-plus",
    "github:Cohere-command-r-plus-08-2024",
    "github:Cohere-embed-v3-english",
    "github:Cohere-embed-v3-multilingual",
    "github:DeepSeek-R1",
    "github:DeepSeek-R1-0528",
    "github:DeepSeek-V3",
    "github:DeepSeek-V3-0324",
    "github:DeepSeek-V3.1",
    "github:EvoDiff",
    "github:Flux-1.1-Pro",
    "github:Flux.1-Kontext-pro",
    "github:Llama-3.2-11B-Vision-Instruct",
    "github:Llama-3.2-90B-Vision-Instruct",
    "github:Llama-3.3-70B-Instruct",
    "github:Llama-4-Maverick-17B-128E-Instruct-FP8",
    "github:Llama-4-Scout-17B-16E",
    "github:Llama-4-Scout-17B-16E-Instruct",
    "github:MAI-DS-R1",
    "github:MatterGen",
    "github:Meta-Llama-3-70B-Instruct",
    "github:Meta-Llama-3-8B-Instruct",
    "github:Meta-Llama-3.1-405B-Instruct",
    "github:Meta-Llama-3.1-70B-Instruct",
    "github:Meta-Llama-3.1-8B-Instruct",
    "github:Ministral-3B",
    "github:Ministral-8B",
    "github:Mistral-Large-2411",
    "github:Mistral-Large-3",
    "github:Mistral-Nemo",
    "github:Mistral-large-2407",
    "github:Mistral-small",
    "github:Muse",
    "github:Phi-4-mini-flash-reasoning",
    "github:Phi-4-reasoning-plus",
    "github:codex-mini",
    "github:cohere-command-a",
    "github:computer-use-preview",
    "github:embed-v-4-0",
    "github:financial-reports-analysis-v2",
    "github:gpt-4.1",
    "github:gpt-4.1-mini",
    "github:gpt-4.1-nano",
    "github:gpt-4.5-preview",
    "github:gpt-4o",
    "github:gpt-4o-mini",
    "github:gpt-4o-mini-transcribe",
    "github:gpt-4o-mini-tts",
    "github:gpt-4o-transcribe",
    "github:gpt-4o-transcribe-diarize",
    "github:gpt-5",
    "github:gpt-5-chat",
    "github:gpt-5-codex",
    "github:gpt-5-mini",
    "github:gpt-5-nano",
    "github:gpt-5.1",
    "github:gpt-5.1-codex",
    "github:gpt-5.1-codex-max",
    "github:gpt-5.1-codex-mini",
    "github:gpt-image-1",
    "github:gpt-image-1-mini",
    "github:grok-3",
    "github:grok-3-mini",
    "github:jais-30b-chat",
    "github:mistral-document-ai-2505",
    "github:mistral-medium-2505",
    "github:mistral-ocr-2503",
    "github:mistral-small-2503",
    "github:model-router",
    "github:o3-deep-research",
    "github:o3-pro",
    "github:retrochimera",
    "github:sora",
    "github:sora-2",
    "github:supply-chain-trade-regulations-v2",
]

__all__ = ["GithubModels"]
