"""Generated model names for openrouter provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 156
"""

from __future__ import annotations

from typing import Literal


OpenrouterModels = Literal[
    "openrouter:ai21/jamba-large-1.7",
    "openrouter:ai21/jamba-mini-1.7",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b",
    "openrouter:alibaba/tongyi-deepresearch-30b-a3b:free",
    "openrouter:allenai/olmo-3-32b-think:free",
    "openrouter:allenai/olmo-3-7b-instruct",
    "openrouter:allenai/olmo-3-7b-think",
    "openrouter:amazon/nova-2-lite-v1",
    "openrouter:amazon/nova-2-lite-v1:free",
    "openrouter:amazon/nova-premier-v1",
    "openrouter:anthropic/claude-haiku-4.5",
    "openrouter:anthropic/claude-opus-4.1",
    "openrouter:anthropic/claude-opus-4.5",
    "openrouter:anthropic/claude-sonnet-4.5",
    "openrouter:arcee-ai/trinity-mini",
    "openrouter:arcee-ai/trinity-mini:free",
    "openrouter:baidu/ernie-4.5-21b-a3b",
    "openrouter:baidu/ernie-4.5-21b-a3b-thinking",
    "openrouter:baidu/ernie-4.5-300b-a47b",
    "openrouter:baidu/ernie-4.5-vl-28b-a3b",
    "openrouter:baidu/ernie-4.5-vl-424b-a47b",
    "openrouter:bytedance/ui-tars-1.5-7b",
    "openrouter:cognitivecomputations/dolphin-mistral-24b-venice-edition:free",
    "openrouter:deepcogito/cogito-v2-preview-llama-109b-moe",
    "openrouter:deepcogito/cogito-v2-preview-llama-405b",
    "openrouter:deepcogito/cogito-v2-preview-llama-70b",
    "openrouter:deepcogito/cogito-v2.1-671b",
    "openrouter:deepseek/deepseek-chat-v3.1",
    "openrouter:deepseek/deepseek-r1-0528",
    "openrouter:deepseek/deepseek-r1-0528-qwen3-8b",
    "openrouter:deepseek/deepseek-v3.1-terminus",
    "openrouter:deepseek/deepseek-v3.1-terminus:exacto",
    "openrouter:deepseek/deepseek-v3.2",
    "openrouter:deepseek/deepseek-v3.2-exp",
    "openrouter:deepseek/deepseek-v3.2-speciale",
    "openrouter:essentialai/rnj-1-instruct",
    "openrouter:google/gemini-2.5-flash",
    "openrouter:google/gemini-2.5-flash-image",
    "openrouter:google/gemini-2.5-flash-image-preview",
    "openrouter:google/gemini-2.5-flash-lite",
    "openrouter:google/gemini-2.5-flash-lite-preview-09-2025",
    "openrouter:google/gemini-2.5-flash-preview-09-2025",
    "openrouter:google/gemini-2.5-pro",
    "openrouter:google/gemini-2.5-pro-preview",
    "openrouter:google/gemini-3-pro-image-preview",
    "openrouter:google/gemini-3-pro-preview",
    "openrouter:google/gemma-3n-e2b-it:free",
    "openrouter:ibm-granite/granite-4.0-h-micro",
    "openrouter:inception/mercury",
    "openrouter:kwaipilot/kat-coder-pro:free",
    "openrouter:liquid/lfm-2.2-6b",
    "openrouter:liquid/lfm2-8b-a1b",
    "openrouter:meituan/longcat-flash-chat",
    "openrouter:meituan/longcat-flash-chat:free",
    "openrouter:minimax/minimax-m1",
    "openrouter:minimax/minimax-m2",
    "openrouter:mistralai/codestral-2508",
    "openrouter:mistralai/devstral-medium",
    "openrouter:mistralai/devstral-small",
    "openrouter:mistralai/ministral-14b-2512",
    "openrouter:mistralai/ministral-3b-2512",
    "openrouter:mistralai/ministral-8b-2512",
    "openrouter:mistralai/mistral-large-2512",
    "openrouter:mistralai/mistral-medium-3.1",
    "openrouter:mistralai/mistral-small-3.2-24b-instruct",
    "openrouter:mistralai/voxtral-small-24b-2507",
    "openrouter:moonshotai/kimi-dev-72b",
    "openrouter:moonshotai/kimi-k2",
    "openrouter:moonshotai/kimi-k2-0905",
    "openrouter:moonshotai/kimi-k2-0905:exacto",
    "openrouter:moonshotai/kimi-k2-thinking",
    "openrouter:moonshotai/kimi-k2:free",
    "openrouter:moonshotai/kimi-linear-48b-a3b-instruct",
    "openrouter:morph/morph-v3-fast",
    "openrouter:morph/morph-v3-large",
    "openrouter:nousresearch/hermes-4-405b",
    "openrouter:nousresearch/hermes-4-70b",
    "openrouter:nvidia/llama-3.3-nemotron-super-49b-v1.5",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl",
    "openrouter:nvidia/nemotron-nano-12b-v2-vl:free",
    "openrouter:nvidia/nemotron-nano-9b-v2",
    "openrouter:nvidia/nemotron-nano-9b-v2:free",
    "openrouter:openai/gpt-4o-audio-preview",
    "openrouter:openai/gpt-5",
    "openrouter:openai/gpt-5-chat",
    "openrouter:openai/gpt-5-codex",
    "openrouter:openai/gpt-5-image",
    "openrouter:openai/gpt-5-image-mini",
    "openrouter:openai/gpt-5-mini",
    "openrouter:openai/gpt-5-nano",
    "openrouter:openai/gpt-5-pro",
    "openrouter:openai/gpt-5.1",
    "openrouter:openai/gpt-5.1-chat",
    "openrouter:openai/gpt-5.1-codex",
    "openrouter:openai/gpt-5.1-codex-max",
    "openrouter:openai/gpt-5.1-codex-mini",
    "openrouter:openai/gpt-oss-120b",
    "openrouter:openai/gpt-oss-120b:exacto",
    "openrouter:openai/gpt-oss-120b:free",
    "openrouter:openai/gpt-oss-20b",
    "openrouter:openai/gpt-oss-20b:free",
    "openrouter:openai/gpt-oss-safeguard-20b",
    "openrouter:openai/o3-deep-research",
    "openrouter:openai/o3-pro",
    "openrouter:openai/o4-mini-deep-research",
    "openrouter:opengvlab/internvl3-78b",
    "openrouter:openrouter/bodybuilder",
    "openrouter:perplexity/sonar-pro-search",
    "openrouter:prime-intellect/intellect-3",
    "openrouter:qwen/qwen-plus-2025-07-28",
    "openrouter:qwen/qwen-plus-2025-07-28:thinking",
    "openrouter:qwen/qwen3-235b-a22b-2507",
    "openrouter:qwen/qwen3-235b-a22b-thinking-2507",
    "openrouter:qwen/qwen3-30b-a3b-instruct-2507",
    "openrouter:qwen/qwen3-30b-a3b-thinking-2507",
    "openrouter:qwen/qwen3-coder",
    "openrouter:qwen/qwen3-coder-30b-a3b-instruct",
    "openrouter:qwen/qwen3-coder-flash",
    "openrouter:qwen/qwen3-coder-plus",
    "openrouter:qwen/qwen3-coder:exacto",
    "openrouter:qwen/qwen3-coder:free",
    "openrouter:qwen/qwen3-max",
    "openrouter:qwen/qwen3-next-80b-a3b-instruct",
    "openrouter:qwen/qwen3-next-80b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-235b-a22b-instruct",
    "openrouter:qwen/qwen3-vl-235b-a22b-thinking",
    "openrouter:qwen/qwen3-vl-30b-a3b-instruct",
    "openrouter:qwen/qwen3-vl-30b-a3b-thinking",
    "openrouter:qwen/qwen3-vl-8b-instruct",
    "openrouter:qwen/qwen3-vl-8b-thinking",
    "openrouter:relace/relace-apply-3",
    "openrouter:relace/relace-search",
    "openrouter:stepfun-ai/step3",
    "openrouter:switchpoint/router",
    "openrouter:tencent/hunyuan-a13b-instruct",
    "openrouter:thedrummer/anubis-70b-v1.1",
    "openrouter:thedrummer/cydonia-24b-v4.1",
    "openrouter:thudm/glm-4.1v-9b-thinking",
    "openrouter:tngtech/deepseek-r1t2-chimera",
    "openrouter:tngtech/deepseek-r1t2-chimera:free",
    "openrouter:tngtech/tng-r1t-chimera",
    "openrouter:tngtech/tng-r1t-chimera:free",
    "openrouter:x-ai/grok-3",
    "openrouter:x-ai/grok-3-mini",
    "openrouter:x-ai/grok-4",
    "openrouter:x-ai/grok-4-fast",
    "openrouter:x-ai/grok-4.1-fast",
    "openrouter:x-ai/grok-code-fast-1",
    "openrouter:z-ai/glm-4-32b",
    "openrouter:z-ai/glm-4.5",
    "openrouter:z-ai/glm-4.5-air",
    "openrouter:z-ai/glm-4.5-air:free",
    "openrouter:z-ai/glm-4.5v",
    "openrouter:z-ai/glm-4.6",
    "openrouter:z-ai/glm-4.6:exacto",
    "openrouter:z-ai/glm-4.6v",
]

__all__ = ["OpenrouterModels"]
