"""Generated model names for copilot provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 17
"""

from __future__ import annotations

from typing import Literal


CopilotModels = Literal[
    "copilot:claude-haiku-4.5",
    "copilot:claude-opus-4.5",
    "copilot:claude-sonnet-4",
    "copilot:claude-sonnet-4.5",
    "copilot:gemini-2.5-pro",
    "copilot:gemini-3-pro-preview",
    "copilot:gpt-4.1",
    "copilot:gpt-4o",
    "copilot:gpt-5",
    "copilot:gpt-5-codex",
    "copilot:gpt-5-mini",
    "copilot:gpt-5.1",
    "copilot:gpt-5.1-codex",
    "copilot:gpt-5.1-codex-max",
    "copilot:gpt-5.1-codex-mini",
    "copilot:grok-code-fast-1",
    "copilot:oswe-vscode-prime",
]

__all__ = ["CopilotModels"]
