"""Generated model names for openai provider.

Auto-generated by scripts/generate_model_names.py - do not edit manually.
Total models: 12
"""

from __future__ import annotations

from typing import Literal


OpenaiModels = Literal[
    "openai:gpt-5",
    "openai:gpt-5-chat-latest",
    "openai:gpt-5-codex",
    "openai:gpt-5-mini",
    "openai:gpt-5-nano",
    "openai:gpt-5-pro",
    "openai:gpt-5.1",
    "openai:gpt-5.1-chat-latest",
    "openai:gpt-5.1-codex",
    "openai:gpt-5.1-codex-max",
    "openai:gpt-5.1-codex-mini",
    "openai:o3-pro",
]

__all__ = ["OpenaiModels"]
